function [Profile, StartingNode] = LongProfile(dem,S,thresh)
%Leif Karlstorm
%Script to calculate long profile 
%inputs: original DEM, matrix containing Strahler channel order, vector
%containing intersection nodes, threshold to just look at one S order

%output - Profile corresponding to that order


%this parameter controls the order of the channel being extracted:
%max(S(:)) is the largest channel in the image
%thresh=max(S(:));

%-------------------------------------------------------------------------

%first get intersection of Stahler channel and DEM
NR=length(S(:,1));
NC=length(S(1,:));

P1=zeros(size(dem));

P1(S==thresh)=dem(S==thresh);

BP = bwmorph(P1, 'thin',Inf);
P1(BP==0)=0;


CC=bwconncomp(BP==1);
%find number of streams in dem of given order thresh
if(thresh==max(S(:)))
    Num=1;
else

Num=uint8(CC.NumObjects);
end

%array of already traveled nodes
  Route=zeros(size(dem));  
    
for j=1:Num
    clear Sx Sy
     
    if(Num>1)
clear Path
Path = CC.PixelIdxList{j}; %linear indices of stream

[miny minx]=ind2sub([NR NC],min(Path));
%[maxx maxy]=ind2sub(Sindmx,NR,NC);

    else
[miny minx]=find(P1==min(dem(S==thresh)));

if(length(miny)>1)
    my=miny(1);
    mx=minx(1);
    clear miny minx
    miny=my;
    minx=mx;
end
[Smax Sindmx]=max(dem(S==thresh));

%[minx miny]=ind2sub([NR NC],Sindm);
[maxx maxy]=ind2sub([NR NC],Sindmx);
    end
    
Sx(1)=minx; 
Sy(1)=miny;

Route(Sy(1),Sx(1))=1;

%create ordered vector with the stream nodes going upstream
for is=2:length(CC.PixelIdxList{j})-1
    
        if(Sy(is-1)+1>0&&Sy(is-1)+1<NR&&Sx(is-1)>0&&P1(Sy(is-1)+1,Sx(is-1))>0 &&Route(Sy(is-1)+1,Sx(is-1))==0)
            Sy(is)=Sy(is-1)+1;
            Sx(is)=Sx(is-1);
            Route(Sy(is-1)+1,Sx(is-1))=1;
        elseif(Sy(is-1)+1>0&&Sy(is-1)+1<NR&&Sx(is-1)-1>0&&P1(Sy(is-1)+1,Sx(is-1)-1)>0 &&Route(Sy(is-1)+1,Sx(is-1)-1)==0)
            Sy(is)=Sy(is-1)+1;
            Sx(is)=Sx(is-1)-1;
            Route(Sy(is-1)+1,Sx(is-1)-1)=1;
        elseif(Sy(is-1)+1>0&&Sy(is-1)+1<NR&&Sx(is-1)+1>0&&P1(Sy(is-1)+1,Sx(is-1)+1)>0 &&Route(Sy(is-1)+1,Sx(is-1)+1)==0)
            Sy(is)=Sy(is-1)+1;
            Sx(is)=Sx(is-1)+1;
            Route(Sy(is-1)+1,Sx(is-1)+1)=1;
        elseif(Sy(is-1)+1>0&&Sy(is-1)>0&&Sx(is-1)+1>0&&P1(Sy(is-1),Sx(is-1)-1)>0 &&Route(Sy(is-1),Sx(is-1)-1)==0)
            Sy(is)=Sy(is-1);
            Sx(is)=Sx(is-1)-1;
            Route(Sy(is-1),Sx(is-1)-1)=1;          
        elseif(Sy(is-1)>0&&Sx(is-1)-1>0&&P1(Sy(is-1),Sx(is-1)+1)>0 &&Route(Sy(is-1),Sx(is-1)+1)==0)
            Sy(is)=Sy(is-1);
            Sx(is)=Sx(is-1)+1;
            Route(Sy(is-1),Sx(is-1)+1)=1;          
        elseif(Sy(is-1)-1>0&&Sx(is-1)-1>0&&P1(Sy(is-1)-1,Sx(is-1)-1)>0 &&Route(Sy(is-1)-1,Sx(is-1)-1)==0)
            Sy(is)=Sy(is-1)-1;
            Sx(is)=Sx(is-1)-1;
            Route(Sy(is-1)-1,Sx(is-1)-1)=1;            
        elseif(Sy(is-1)-1>0&&Sx(is-1)>0&&P1(Sy(is-1)-1,Sx(is-1))>0 &&Route(Sy(is-1)-1,Sx(is-1))==0)
            Sy(is)=Sy(is-1)-1;
            Sx(is)=Sx(is-1);
            Route(Sy(is-1)-1,Sx(is-1))=1;           
        elseif(Sy(is-1)-1>0&&Sx(is-1)+1>0&&P1(Sy(is-1)-1,Sx(is-1)+1)>0 &&Route(Sy(is-1)-1,Sx(is-1)+1)==0) 
            Sy(is)=Sy(is-1)-1;
            Sx(is)=Sx(is-1)+1;
            Route(Sy(is-1)-1,Sx(is-1)+1)=1;  
        else
            %keyboard
            break
        end
        
        
        Sv(is)=dem(Sy(is),Sx(is));
end
 
eval(['Profile.Num' num2str(j) '=Sv;']);
eval(['StartingNode.Num' num2str(j) '=sub2ind([NR NC],Sy(1),Sx(1));']);

end










