%Leif Karlstrom 
%EPS 209 Final Project code

%This script takes an input DEM, applies curvature based filtering to
%explote channel extraction via this method

%Finding that purely filter based channel extraction is not ideal, it then
%applies a flow routing routine and Strahler Channel order routine
%available on Matlab File exchange:
%http://www.mathworks.com/matlabcentral/fileexchange/22952

%Finally, it extracts a long profile from channels of a given order, and
%graphs it.

addpath topotoolbox-1.04-r2

%load DEM
DEMs=load('GC_DEMex.mat');
dem=DEMs.DEM;

%%Curvature filtering part

% smooth (median)
fSize = 1; 
Si = medfilt2(dem, [fSize fSize]);

H = fspecial('log',35,.1);

S=imfilter(dem,H,'replicate');

Thresh=.01e4;
Ny=length(S(:,1));Nx=length(S(1,:));
ST=zeros(Ny,Nx);
ST(S>Thresh)=1;

figure; imshow(ST)

SO = bwareaopen(ST, 10000,8);

Skel = bwmorph(SO, 'skel', Inf);

Skel = bwmorph(Skel, 'thin',Inf);

BP = bwmorph(Skel, 'branchpoints');

SkelFill = Skel;
SkelFill(BP==1)=10;

figure; imshow(Skel);

%% Flow routing calc and Strahler channel order

[X,Y]=meshgrid([1:length(dem(1,:))],[1:length(dem(:,1))]);
f=figure(3);
surf(X,Y,dem); 
axis image; 
shading interp; 
camlight

% Fill sinks
%
% Often DEMs feature erroneous topographic depressions that should be
% filled prior to flow path computation. You can obtain this by using the
% function |fillsinks|. 

dem = fillsinks(dem);


%get Strahler channel order
 [A,M] = wflowacc(X,Y,dem,'type','single');
% % let's simply assume that channels start where
% % A is larger than 400;
 W = A>400;
% % and calculate the strahler stream order
 [S,nodes] = streamorder(M,W);
 %thin to eliminate thick channels
 
  Sk = bwmorph(S, 'skel', Inf);

 figure;
 pcolor(X,Y,S); axis image; shading flat;
 colorbar
 hold on
 plot(X(nodes),Y(nodes),'ks','MarkerFaceColor','g')
 title('Strahler Stream Order')
 
 %calculate long profile
 
 %this parameter controls the order of the channel being extracted:
%max(S(:)) is the largest channel in the image
 thresh=max(S(:))-1;
 
 [Profile, StartingNode] = LongProfile(dem,S,thresh);
 
 figure; plot(Profile.Num1)
 title('Sample Long Profile')
xlabel('Distance along channel (m)')
ylabel('Elevation (m)')
