function N = flowconvergence(M,siz)

% compute flow convergence of a digital elevation model
% 
% Syntax
%
%     N = flowconvergence(M,siz)
%
% Description
%
%     flowconvergence computes the number of neighboring cells that 
%     drain into each cell. Values in N range between 0 on ridges to 8 in
%     pits. N can thus be used as a measure of flow convergence in a
%     digital elevation model. flowconvergence works with flow direction
%     matrices generated by the flowdir algorithm with option 'single' and
%     'multi'.
%
% Input
%
%     M       flow direction matrix
%     siz     two element vector containing the number of rows and columns
%             of the DEM from which the flow direction matrix was
%             calculated.
%
% Output
%
%     N       matrix containing the sum of contributing neighbor cells. 
%             N contains integers only, when M is a single flow direction
%             matrix.
%
% Example
% 
%     load exampleDEM
%     M = flowdir(X,Y,dem,'exponent',5);
%     N = flowconvergence(M,size(dem));
%     surf(X,Y,dem,N)
% 
%
% See also: FLOWDIR
%
% Author: Wolfgang Schwanghart (w.schwanghart[at]unibas.ch)
% Date: 15. March, 2009



error(nargchk(1, 1, nargin));

N = full(sum(M,1));
N = reshape(N,siz);